@@ -479,9 +479,12 @@ read_config(AppletConfig *config){
     /* start timer for read data from device temperature sensor */
     if(config->use_sensor){
 	read_sensor(FALSE);
-	app->sensor_timer = g_timeout_add(config->sensor_update_time * 1000 * 60,
-                                            (GtkFunction)read_sensor,
-                                            GINT_TO_POINTER(1));
+	if (config->sensor_update_time)
+	    app->sensor_timer = g_timeout_add(config->sensor_update_time * 1000 * 60,
+                                        	(GtkFunction)read_sensor,
+                                        	GINT_TO_POINTER(1));
+        else
+    	    app->sensor_timer = 0;
     }else
       app->sensor_timer = 0;
     /* Get value of transparence default 0 */
